﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Diagnostics;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using Windows.UI.Xaml.Input;

namespace XamlInWindows10
{
    public class Game : INotifyPropertyChanged
    {
        #region Fields
        private string _white;
        private string _black;
        private string _event;
        private string _site;
        private string _date;
        private string _result;
        private string _round;
        #endregion

        #region Properties
        public string White
        {
            get { return _white; }
            set { SetProperty(ref _white, value); }
        }
        public string Black
        {
            get { return _black; }
            set { SetProperty(ref _black, value); }
        }
        public string Event
        {
            get { return _event; }
            set { SetProperty(ref _event, value); }
        }
        public string Site
        {
            get { return _site; }
            set { SetProperty(ref _site, value); }
        }
        public string Date
        {
            get { return _date; }
            set { SetProperty(ref _date, value); }
        }
        public string Result
        {
            get { return _result; }
            set { SetProperty(ref _result, value); }
        }
        public string Round
        {
            get { return _round; }
            set { SetProperty(ref _round, value); }
        }
        #endregion

        #region INotifyPropertyChanged
        protected bool SetProperty<T>(ref T storage, T value, [CallerMemberName] String propertyName = null)
        {
            if (object.Equals(storage, value)) return false;

            storage = value;
            this.OnPropertyChanged(propertyName);
            return true;
        }

        protected void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
        #endregion

        #region Methods
        public void Save()
        {
            Debug.WriteLine(string.Format("Saving Game {0} - {1}", White, Black));
        }
        #endregion

        #region Construction
        public Game(string white, string black, string evt, string site, string date, string result, string round)
        {
            this.White = white;
            this.Black = black;
            this.Event = evt;
            this.Site = site;
            this.Date = date;
            this.Result = result;
            this.Round = round;
        }
    #endregion
    }

    public class RelativePanelViewModel : Game
    {
        public RelativePanelViewModel() : base("Karpov", "Kasparov", "World Championship 1990", "New York", "08.10.1990", "1/2-1/2", "01")
        {
        }
    }

    public class GameList: ObservableCollection<Game>
    {
        public GameList()
        {
            Add(new Game("Karpov", "Kasparov", "World Championship 1990", "New York", "1990.10.08", "½-½", "01"));
            Add(new Game("Kasparov", "Karpov", "World Championship 1990", "New York", "1990.10.10", "1-0", "02"));
            Add(new Game("Karpov", "Kasparov", "World Championship 1990", "New York", "1990.10.15", "½-½", "03"));
            Add(new Game("Kasparov", "Karpov", "World Championship 1990", "New York", "1990.10.17", "½-½", "04"));
            Add(new Game("Karpov", "Kasparov", "World Championship 1990", "New York", "1990.10.22", "½-½", "05"));
            Add(new Game("Kasparov", "Karpov", "World Championship 1990", "New York", "1990.10.24", "½-½", "06"));
            Add(new Game("Karpov", "Kasparov", "World Championship 1990", "New York", "1990.10.26", "1-0", "07"));
            Add(new Game("Kasparov", "Karpov", "World Championship 1990", "New York", "1990.10.29", "½-½", "08"));
            Add(new Game("Karpov", "Kasparov", "World Championship 1990", "New York", "1990.10.31", "½-½", "09"));
            Add(new Game("Kasparov", "Karpov", "World Championship 1990", "New York", "1990.11.03", "½-½", "10"));
            Add(new Game("Karpov", "Kasparov", "World Championship 1990", "New York", "1990.11.05", "½-½", "11"));
            Add(new Game("Kasparov", "Karpov", "World Championship 1990", "New York", "1990.11.07", "½-½", "12"));
            Add(new Game("Karpov", "Kasparov", "World Championship 1990", "Lyon", "1990.11.24", "½-½", "13"));
            Add(new Game("Kasparov", "Karpov", "World Championship 1990", "Lyon", "1990.11.26", "½-½", "14"));
            Add(new Game("Karpov", "Kasparov", "World Championship 1990", "Lyon", "1990.11.28", "½-½", "15"));
            Add(new Game("Kasparov", "Karpov", "World Championship 1990", "Lyon", "1990.12.01", "1-0", "16"));
            Add(new Game("Karpov", "Kasparov", "World Championship 1990", "Lyon", "1990.12.05", "1-0", "17"));
            Add(new Game("Kasparov", "Karpov", "World Championship 1990", "Lyon", "1990.12.08", "1-0", "18"));
            Add(new Game("Karpov", "Kasparov", "World Championship 1990", "Lyon", "1990.12.12", "½-½", "19"));
            Add(new Game("Kasparov", "Karpov", "World Championship 1990", "Lyon", "1990.12.15", "1-0", "20"));
            Add(new Game("Karpov", "Kasparov", "World Championship 1990", "Lyon", "1990.12.19", "½-½", "21"));
            Add(new Game("Kasparov", "Karpov", "World Championship 1990", "Lyon", "1990.12.26", "½-½", "22"));
            Add(new Game("Karpov", "Kasparov", "World Championship 1990", "Lyon", "1990.12.29", "1-0", "23"));
            Add(new Game("Kasparov", "Karpov", "World Championship 1990", "Lyon", "1990.12.31", "½-½", "24"));
        }
    }
}
