﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using Windows.ApplicationModel.DataTransfer;
using Windows.UI.Xaml.Media.Imaging;
using Windows.Storage.Streams;
using Windows.Graphics.Imaging;
using System.Threading.Tasks;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace XamlInWindows10
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class DragDropPage : Page
    {
        public DragDropPage()
        {
            this.InitializeComponent();
        }

        private void BackButton_Click(object sender, RoutedEventArgs e)
        {
            if (Frame.CanGoBack)
            {
                Frame.GoBack();
            }
        }

        private async void Border_DragStarting(UIElement sender, DragStartingEventArgs args)
        {
            string text = "Drag started at " + DateTime.Now.ToString();
            args.Data.SetText(text);
            args.Data.RequestedOperation = DataPackageOperation.Copy;
            if (UseDataRB.IsChecked.HasValue && UseDataRB.IsChecked.Value)
            {
                args.DragUI.SetContentFromDataPackage();
            }
            else if (CustomVisualRB.IsChecked.HasValue && CustomVisualRB.IsChecked.Value)
            {
                var deferral = args.GetDeferral();
                HiddenTextBlock.Text = text;
                RenderTargetBitmap rtb = new RenderTargetBitmap();
                await rtb.RenderAsync(HiddenBorder);
                IBuffer buffer = await rtb.GetPixelsAsync();
                SoftwareBitmap sb = SoftwareBitmap.CreateCopyFromBuffer(buffer, BitmapPixelFormat.Bgra8, rtb.PixelWidth, rtb.PixelHeight, BitmapAlphaMode.Premultiplied);
                args.DragUI.SetContentFromSoftwareBitmap(sb);
                deferral.Complete();
            }
        }

        private void Border_DragOverOrEnter(object sender, DragEventArgs e)
        {
            if (e.DataView.Contains(StandardDataFormats.Text))
            {
                e.AcceptedOperation = DataPackageOperation.Copy;
                e.DragUIOverride.IsGlyphVisible = false;
                e.DragUIOverride.IsContentVisible = false;
                e.DragUIOverride.Caption = "Drop here to insert text";
                e.DragUIOverride.IsCaptionVisible = true;
            }
            else if (e.DataView.Contains(StandardDataFormats.StorageItems))
            {
                e.AcceptedOperation = DataPackageOperation.Copy;
                e.DragUIOverride.IsGlyphVisible = false;
                e.DragUIOverride.Caption = "Drop here to attach files";
            }
            else
            {
                e.AcceptedOperation = DataPackageOperation.None;
            }
        }
        private async void Border_Drop(object sender, DragEventArgs e)
        {
            if (e.DataView.Contains(StandardDataFormats.Text))
            {
                e.AcceptedOperation = DataPackageOperation.Copy;
                var items = new List<string>();
                items.Add("Dropped text");
                items.Add(await e.DataView.GetTextAsync());
                DroppedInfoListView.ItemsSource = items;
                e.Handled = true;
            }
            else if (e.DataView.Contains(StandardDataFormats.StorageItems))
            {
                e.AcceptedOperation = DataPackageOperation.Copy;
                var items = new List<string>();
                items.Add("Dropped files");
                foreach (var storageItem in await e.DataView.GetStorageItemsAsync())
                {
                    items.Add(storageItem.Name);
                }
                DroppedInfoListView.ItemsSource = items;
                e.Handled = true;
            }
            else
            {
                e.AcceptedOperation = DataPackageOperation.None;
                e.Handled = true;
            }
        }

    }
}
