﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.Foundation;
using Windows.UI.Xaml;

namespace XamlInWindows10
{
    public class SmallWindowTrigger : StateTriggerBase
    {
        double _maxWindowHeight = double.MaxValue;
        public SmallWindowTrigger()
        {
            Window.Current.SizeChanged += (sender, e) => EvaluateTrigger();
        }
        private void EvaluateTrigger()
        {
            Rect bounds = Window.Current.Bounds;
            SetActive(bounds.Height < _maxWindowHeight);
        }
        public double MaxWindowHeight
        {
            set
            {
                _maxWindowHeight = value;
                EvaluateTrigger();
            }
        }
    }

    public class ConnectedTrigger : StateTriggerBase
    {
        public static event EventHandler OnConnectedChange;
        private static bool _isConnected = false;
        public static bool IsConnected
        {
            get { return _isConnected; }
            set
            {
                if (_isConnected != value)
                {
                    _isConnected = value;
                    if (OnConnectedChange != null)
                    {
                        OnConnectedChange(null, null);
                    }
                }
            }
        }

        bool? _connected;
        public ConnectedTrigger()
        {
            OnConnectedChange += ConnectedTrigger_OnConnectedChange;
        }
        public bool Connected
        {
            set
            {
                _connected = value;
                EvaluateCondition();
            }
        }

        private void ConnectedTrigger_OnConnectedChange(object sender, EventArgs e)
        {
            if (_connected.HasValue) EvaluateCondition();
        }

        void EvaluateCondition()
        {
            if (_connected.HasValue)
            {
                base.SetActive(_connected.Value == _isConnected);
            }
        }
    }
}
